@@ -1,5 +1,5 @@
-# ZestyParser 0.5.2 -- Parses in Python zestily
-# Copyright (C) 2006 Adam Atlas
+# ZestyParser 0.7.0 -- Parses in Python zestily
+# Copyright (C) 2006-2007 Adam Atlas
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -16,13 +16,13 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 '''
-@version: 0.6.0
+@version: 0.7.0
 @author: Adam Atlas
 @copyright: Copyright 2006-2007 Adam Atlas. Released under the terms of the GNU General Public License.
 @contact: adam@atlas.st
 '''
 
-__all__ = ('ZestyParser', 'NotMatched', 'ParseError', 'CallbackFor')
+__all__ = ('ZestyParser', 'NotMatched', 'ParseError', 'CallbackFor', 'DebugNote')
 
 class Error(Exception): pass
 class NotMatched(Error): '''Raised by a token if it has failed to match at the parser's current cursor.'''
@@ -40,7 +40,7 @@ class ParseError(Error):
 		'''Prints the error message and the row and column corresponding to the parser's cursor.'''
 		return "%s at line %i column %i" % (self.message, self.coord[0], self.coord[1])
 
-class CallbackFor:
+def CallbackFor(token):
 	'''
 	Function decorator indicating that the function should be set as the callback of the given token; returns the token instead of the function.
 	
@@ -54,12 +54,22 @@ class CallbackFor:
 			print r
 		T_INT = Token('([0-9]+)', callback=T_INT)
 	'''
-	def __init__(self, token):
-		self.token = token
+	def newFunc(func):
+		return token >> func
+	return newFunc
+
+def DebugNote(note):
+	'''
+	Factory which creates a logging function usable as a token callback. The logging function prints L{note}, the parser's coordinates, and the value matched. It then returns the value unmodified.
 	
-	def __call__(self, func):
-		self.token.callback = func
-		return self.token
+	Example::
+		T_FOO = TokenSeries(RawToken('foo')) >> DebugNote('foo_series')
+	'''
+	def func(parser, val, cursor):
+		coord = parser.coord()
+		print '%s(%i, %i): %s' % (note, coord[0], coord[1], val)
+		return val
+	return func
 
 class ZestyParser:
 	'''
@@ -97,34 +107,30 @@ class ZestyParser:
 		self.cursor = 0
 		self.len = len(data)
 	
-	def scan(self, tokens):
+	def scan(self, token):
 		'''
 		Scan for one token.
 		
-		@param tokens: One token, or an iterable of tokens (in which case any of them may match).
-		@return: The return value of the matching token, or None if the token iterable is empty or if all tokens raised NotMatched.
+		@param token: The token to scan for.
+		@return: The return value of the matching token, or None if the token raised NotMatched.
 		@rtype: object
 		@raise ParseError: If a token fails to match and it has a failMessage parameter.
 		'''
-		if not hasattr(tokens, '__iter__'):
-			tokens = (tokens,)
-		for t in tokens:
-			oldCursor = self.cursor
-			try:
-				r = t(self, oldCursor)
-				self.last = t
-				return r
-			except NotMatched:
-				self.cursor = oldCursor
-				if hasattr(t, 'failMessage') and t.failMessage: raise ParseError(self, t.failMessage)
-		self.last = None
-		return None
+		oldCursor = self.cursor
+		try:
+			r = token(self, oldCursor)
+			self.last = token
+			return r
+		except NotMatched:
+			self.cursor = oldCursor
+			self.last = None
+			return None
 	
 	def skip(self, token):
 		'''
-		Skip one token. This is a convenience method that may be slightly faster than L{scan} when appropriate.
+		A convenience method that skips one token and returns whether it matched.
 		
-		@param token: The token to scan for. (Can't be an iterable as in L{scan}.)
+		@param token: The token to scan for.
 		@type token: token
 		@return: Whether or not the token matched.
 		@rtype: bool
@@ -134,22 +140,28 @@ class ZestyParser:
 			token(self, oldCursor)
 		except NotMatched:
 			self.cursor = oldCursor
-			if hasattr(token, 'failMessage') and token.failMessage: raise ParseError(self, token.failMessage)
-			else: return False
+			return False
 		return True
 	
-	def iter(self, tokens, skip=None, until=None):
+	def iter(self, token, skip=None, until=None):
 		'''
-		Returns an iterator which scans for L{tokens} every time it is invoked.
+		Returns a generator iterator which scans for L{token} every time it is invoked.
 		
-		@param tokens: The tokens to scan for. As with L{scan}, either a single token or an iterable.
-		@param skip: An optional token to L{skip} before each L{scan} for L{tokens}.
+		@param token: The token to scan for.
+		@param skip: An optional token to L{skip} before each L{scan} for L{token}.
 		@type skip: token
-		@param until: An optional 2-tuple. If defined, the iterator will scan for L{tokens} until it reaches the token C{until[0]}; if L{scan} returns C{None} before the iterator encounters this token, it raises a L{ParseError} with the message given in C{until[1]}.
+		@param until: An optional 2-tuple. If defined, the iterator will scan for L{token} until it reaches the token C{until[0]}; if L{scan} returns C{None} before the iterator encounters this token, it raises a L{ParseError} with the message given in C{until[1]}.
 		@type until: tuple
 		@rtype: iterator
 		'''
-		return ParserIterator(tokens, self, skip, until)
+		while 1:
+			if skip: self.skip(skip)
+			if until and self.skip(until[0]): break
+			r = self.scan(token)
+			if self.last: yield r
+			else:
+				if until: raise ParseError(self, until[1])
+				else: break
 	
 	def coord(self, loc=None):
 		'''
@@ -161,26 +173,6 @@ class ZestyParser:
 		@rtype: tuple
 		'''
 		if loc is None: loc = self.cursor
-		row = self.data.count('\n', 0, loc)
+		row = self.data.count('\n', 0, loc) + 1
 		col = loc - self.data.rfind('\n', 0, loc)
-		return (row + 1, col)
-
-class ParserIterator:
-	def __init__(self, tokens, parser, skip=None, until=None):
-		self.tokens = tokens
-		self.parser = parser
-		self.skip = skip
-		self.until = until
-	
-	def __iter__(self): return self
-	
-	def next(self):
-		if self.skip:
-			self.parser.skip(self.skip)
-		if self.until and self.parser.skip(self.until[0]):
-			raise StopIteration
-		r = self.parser.scan(self.tokens)
-		if not self.parser.last:
-			if self.until: raise ParseError(self.parser, self.until[1])
-			else: raise StopIteration
-		return r
\ No newline at end of file
+		return (row, col)
\ No newline at end of file
