@@ -1,4 +1,4 @@
-# ZestyParser 0.6.0 -- Parses in Python zestily
+# ZestyParser 0.7.0 -- Parses in Python zestily
 # Copyright (C) 2006-2007 Adam Atlas
 # 
 # This program is free software; you can redistribute it and/or
@@ -16,15 +16,16 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 '''
-@version: 0.6.0
+@version: 0.7.0
 @author: Adam Atlas
 @copyright: Copyright 2006-2007 Adam Atlas. Released under the terms of the GNU General Public License.
 @contact: adam@atlas.st
 
 @group Parsing: Parser,Tokens
-@group Utilities: AHT
+@group Utilities: AHT,DebuggingParser
 '''
 
 from Parser import *
 from Tokens import *
-from AHT import *
\ No newline at end of file
+from AHT import *
+from DebuggingParser import *
\ No newline at end of file
